@@ -1,8 +1,10 @@
+import asyncio
 import atexit
 import logging
 import gc
 import os
-from sys import exit
+import signal
+import sys
 import warnings
 
 import click
@@ -21,7 +23,6 @@ from distributed.proctitle import (
 
 from toolz import valmap
 from tornado.ioloop import IOLoop, TimeoutError
-from tornado import gen
 
 logger = logging.getLogger("distributed.dask_worker")
 
@@ -267,34 +268,34 @@ def main(
         logger.error(
             "Failed to launch worker.  You cannot use the --port argument when nprocs > 1."
         )
-        exit(1)
+        sys.exit(1)
 
     if nprocs > 1 and not nanny:
         logger.error(
             "Failed to launch worker.  You cannot use the --no-nanny argument when nprocs > 1."
         )
-        exit(1)
+        sys.exit(1)
 
     if contact_address and not listen_address:
         logger.error(
             "Failed to launch worker. "
             "Must specify --listen-address when --contact-address is given"
         )
-        exit(1)
+        sys.exit(1)
 
     if nprocs > 1 and listen_address:
         logger.error(
             "Failed to launch worker. "
             "You cannot specify --listen-address when nprocs > 1."
         )
-        exit(1)
+        sys.exit(1)
 
     if (worker_port or host) and listen_address:
         logger.error(
             "Failed to launch worker. "
             "You cannot specify --listen-address when --worker-port or --host is given."
         )
-        exit(1)
+        sys.exit(1)
 
     try:
         if listen_address:
@@ -308,7 +309,7 @@ def main(
             contact_address = listen_address
     except ValueError as e:
         logger.error("Failed to launch worker. " + str(e))
-        exit(1)
+        sys.exit(1)
 
     if nanny:
         port = nanny_port
@@ -379,20 +380,23 @@ def main(
         for i in range(nprocs)
     ]
 
-    @gen.coroutine
-    def close_all():
+    async def close_all():
         # Unregister all workers from scheduler
         if nanny:
-            yield [n.close(timeout=2) for n in nannies]
+            await asyncio.gather(*[n.close(timeout=2) for n in nannies])
+
+    signal_fired = False
 
     def on_signal(signum):
-        logger.info("Exiting on signal %d", signum)
-        close_all()
+        nonlocal signal_fired
+        signal_fired = True
+        if signum != signal.SIGINT:
+            logger.info("Exiting on signal %d", signum)
+        asyncio.ensure_future(close_all())
 
-    @gen.coroutine
-    def run():
-        yield nannies
-        yield [n.finished() for n in nannies]
+    async def run():
+        await asyncio.gather(*nannies)
+        await asyncio.gather(*[n.finished() for n in nannies])
 
     install_signal_handlers(loop, cleanup=on_signal)
 
@@ -400,7 +404,9 @@ def main(
         loop.run_sync(run)
     except TimeoutError:
         # We already log the exception in nanny / worker. Don't do it again.
-        raise TimeoutError("Timed out starting worker.") from None
+        if not signal_fired:
+            logger.info("Timed out starting worker")
+        sys.exit(1)
     except KeyboardInterrupt:
         pass
     finally:
