@@ -207,7 +207,10 @@ class Cluster(object):
     def _widget_status(self):
         workers = len(self.scheduler_info["workers"])
         if hasattr(self, "worker_spec"):
-            requested = len(self.worker_spec)
+            requested = sum(
+                1 if "group" not in each else len(each["group"])
+                for each in self.worker_spec.values()
+            )
         elif hasattr(self, "workers"):
             requested = len(self.workers)
         else:
@@ -365,7 +368,7 @@ class Cluster(object):
         text = "%s(%r, workers=%d, threads=%d" % (
             self._cluster_class_name,
             self.scheduler_address,
-            len(self.workers),
+            len(self.scheduler_info["workers"]),
             sum(w["nthreads"] for w in self.scheduler_info["workers"].values()),
         )
 
